@@ -1,5 +1,5 @@
--- ntsqlite, an sqlite3 database for nutratracker clients
--- Copyright (C) 2018-2022  Shane Jaroch <nutratracker@gmail.com>
+-- nt-sqlite, an sqlite3 database for embedded clients
+-- Copyright (C) 2018-2022  Shane Jaroch <chown_tee@proton.me>
 --
 -- This program is free software: you can redistribute it and/or modify
 -- it under the terms of the GNU General Public License as published by
@@ -13,37 +13,37 @@
 --
 -- You should have received a copy of the GNU General Public License
 -- along with this program.  If not, see <https://www.gnu.org/licenses/>.
-
-CREATE TABLE version( id integer PRIMARY KEY AUTOINCREMENT, version text NOT NULL, created date NOT NULL, notes text
+CREATE TABLE `version` (
+  id integer PRIMARY KEY AUTOINCREMENT,
+  `version` text NOT NULL UNIQUE,
+  created date NOT NULL,
+  notes text
 );
 
+-- NOTE: INSERT INTO statements for version, bmr_eq, bf_eq? Don't maintain as CSV?
 -- TODO: enforce FK constraint across two DBs?
 --
 ---------------------------------
 -- Equations
 ---------------------------------
-
-CREATE TABLE bmr_eqs (
+CREATE TABLE bmr_eq (
   id integer PRIMARY KEY AUTOINCREMENT,
-  name text NOT NULL
+  name text NOT NULL UNIQUE
 );
 
-CREATE TABLE bf_eqs (
+CREATE TABLE bf_eq (
   id integer PRIMARY KEY AUTOINCREMENT,
-  name text NOT NULL
+  name text NOT NULL UNIQUE
 );
 
 --
 --------------------------------
--- Profiles table
+-- Profile table
 --------------------------------
-
-CREATE TABLE profiles (
+-- TODO: active profile? Decide what belongs here, vs. in prefs.json (if at all)
+CREATE TABLE profile (
   id integer PRIMARY KEY AUTOINCREMENT,
   name text NOT NULL UNIQUE,
-  created int DEFAULT (strftime ('%s', 'now')),
-  updated int DEFAULT (strftime ('%s', 'now')),
-  eula int DEFAULT 0,
   gender text,
   dob date,
   act_lvl int DEFAULT 2, -- [1, 2, 3, 4, 5]
@@ -51,55 +51,20 @@ CREATE TABLE profiles (
   goal_bf real,
   bmr_eq_id int DEFAULT 1,
   bf_eq_id int DEFAULT 1,
-  FOREIGN KEY (bmr_eq_id) REFERENCES bmr_eqs (id) ON UPDATE CASCADE,
-  FOREIGN KEY (bf_eq_id) REFERENCES bf_eqs (id) ON UPDATE CASCADE
+  created int DEFAULT (strftime ('%s', 'now')),
+  FOREIGN KEY (bmr_eq_id) REFERENCES bmr_eq (id) ON UPDATE CASCADE ON DELETE CASCADE,
+  FOREIGN KEY (bf_eq_id) REFERENCES bf_eq (id) ON UPDATE CASCADE ON DELETE CASCADE
 );
 
 --
 --------------------------------
--- Biometrics
+-- Recipe
 --------------------------------
-
-CREATE TABLE biometrics (
-  -- TODO: support custom biometrics and sync?
+CREATE TABLE recipe (
   id integer PRIMARY KEY AUTOINCREMENT,
-  created int DEFAULT (strftime ('%s', 'now')),
-  updated int DEFAULT (strftime ('%s', 'now')),
-  name text NOT NULL UNIQUE,
-  unit text
-);
-
-CREATE TABLE biometric_log (
-  id integer PRIMARY KEY AUTOINCREMENT,
-  profile_id int NOT NULL,
-  created int DEFAULT (strftime ('%s', 'now')),
-  updated int DEFAULT (strftime ('%s', 'now')),
-  date int DEFAULT (strftime ('%s', 'now')),
-  tags text,
-  notes text,
-  FOREIGN KEY (profile_id) REFERENCES profiles (id) ON UPDATE CASCADE
-);
-
-CREATE TABLE bio_log_entry (
-  log_id int NOT NULL,
-  biometric_id int NOT NULL,
-  value real NOT NULL,
-  PRIMARY KEY (log_id, biometric_id),
-  FOREIGN KEY (log_id) REFERENCES biometric_log (id) ON UPDATE CASCADE,
-  FOREIGN KEY (biometric_id) REFERENCES biometrics (id) ON UPDATE CASCADE
-);
-
---
---------------------------------
--- Recipes
---------------------------------
-
-CREATE TABLE recipes (
-  id integer PRIMARY KEY AUTOINCREMENT,
-  created int DEFAULT (strftime ('%s', 'now')),
-  updated int DEFAULT (strftime ('%s', 'now')),
   tagname text NOT NULL UNIQUE,
-  name text NOT NULL UNIQUE
+  name text NOT NULL UNIQUE,
+  created int DEFAULT (strftime ('%s', 'now'))
 );
 
 CREATE TABLE recipe_dat (
@@ -107,21 +72,20 @@ CREATE TABLE recipe_dat (
   food_id int NOT NULL,
   grams real NOT NULL,
   notes text,
+  created int DEFAULT (strftime ('%s', 'now')),
   PRIMARY KEY (recipe_id, food_id),
-  FOREIGN KEY (recipe_id) REFERENCES recipes (id) ON UPDATE CASCADE
+  FOREIGN KEY (recipe_id) REFERENCES recipe (id) ON UPDATE CASCADE ON DELETE CASCADE
 );
 
 --
 --------------------------------
 -- Custom foods
 --------------------------------
-
-CREATE TABLE custom_foods (
+CREATE TABLE custom_food (
   id integer PRIMARY KEY AUTOINCREMENT,
-  created int DEFAULT (strftime ('%s', 'now')),
-  updated int DEFAULT (strftime ('%s', 'now')),
   tagname text NOT NULL UNIQUE,
-  name text NOT NULL UNIQUE
+  name text NOT NULL UNIQUE,
+  created int DEFAULT (strftime ('%s', 'now'))
 );
 
 CREATE TABLE cf_dat (
@@ -129,15 +93,15 @@ CREATE TABLE cf_dat (
   nutr_id int NOT NULL, -- no FK constraining on usda :[
   nutr_val real NOT NULL,
   notes text,
+  created int DEFAULT (strftime ('%s', 'now')),
   PRIMARY KEY (cf_id, nutr_id),
-  FOREIGN KEY (cf_id) REFERENCES custom_foods (id) ON UPDATE CASCADE
+  FOREIGN KEY (cf_id) REFERENCES custom_food (id) ON UPDATE CASCADE ON DELETE CASCADE
 );
 
 --
 --------------------------------
 -- Food (and recipe) logs
 --------------------------------
-
 CREATE TABLE meal_name (
   -- predefined, includes standard three, snacks, brunch, and 3 optional/extra meals
   id integer PRIMARY KEY AUTOINCREMENT,
@@ -147,29 +111,31 @@ CREATE TABLE meal_name (
 CREATE TABLE food_log (
   id integer PRIMARY KEY AUTOINCREMENT,
   profile_id int NOT NULL,
-  created int DEFAULT (strftime ('%s', 'now')),
-  updated int DEFAULT (strftime ('%s', 'now')),
   date int DEFAULT (strftime ('%s', 'now')),
   meal_id int NOT NULL,
-  food_id int NOT NULL,
+  -- NOTE: do we want separate tables for logging `food_id` vs. `custom_food_id`?
+  food_id int,
+  custom_food_id int,
   msre_id int NOT NULL,
   amt real NOT NULL,
-  FOREIGN KEY (profile_id) REFERENCES profiles (id) ON UPDATE CASCADE,
-  FOREIGN KEY (meal_id) REFERENCES meal_name (id) ON UPDATE CASCADE
+  created int DEFAULT (strftime ('%s', 'now')),
+  FOREIGN KEY (profile_id) REFERENCES profile (id) ON UPDATE CASCADE ON DELETE CASCADE,
+  FOREIGN KEY (meal_id) REFERENCES meal_name (id) ON UPDATE CASCADE ON DELETE CASCADE,
+  FOREIGN KEY (custom_food_id) REFERENCES custom_food (id) ON UPDATE CASCADE ON DELETE CASCADE
 );
 
+-- TODO: support msre_id for recipe
 CREATE TABLE recipe_log (
   id integer PRIMARY KEY AUTOINCREMENT,
   profile_id int NOT NULL,
-  created int DEFAULT (strftime ('%s', 'now')),
-  updated int DEFAULT (strftime ('%s', 'now')),
   date int DEFAULT (strftime ('%s', 'now')),
   meal_id int NOT NULL,
   recipe_id int NOT NULL,
   grams real NOT NULL,
-  FOREIGN KEY (profile_id) REFERENCES profiles (id) ON UPDATE CASCADE,
-  FOREIGN KEY (meal_id) REFERENCES meal_name (id) ON UPDATE CASCADE,
-  FOREIGN KEY (recipe_id) REFERENCES recipes (id) ON UPDATE CASCADE
+  created int DEFAULT (strftime ('%s', 'now')),
+  FOREIGN KEY (profile_id) REFERENCES profile (id) ON UPDATE CASCADE ON DELETE CASCADE,
+  FOREIGN KEY (meal_id) REFERENCES meal_name (id) ON UPDATE CASCADE ON DELETE CASCADE,
+  FOREIGN KEY (recipe_id) REFERENCES recipe (id) ON UPDATE CASCADE ON DELETE CASCADE
 );
 
 -- TODO: CREATE TABLE custom_food_log ( ... );
@@ -177,25 +143,61 @@ CREATE TABLE recipe_log (
 --------------------------------
 -- Custom RDAs
 --------------------------------
-
 CREATE TABLE rda (
   profile_id int NOT NULL,
   nutr_id int NOT NULL,
   rda real NOT NULL,
   PRIMARY KEY (profile_id, nutr_id),
-  FOREIGN KEY (profile_id) REFERENCES profiles (id) ON UPDATE CASCADE
+  FOREIGN KEY (profile_id) REFERENCES profile (id) ON UPDATE CASCADE ON DELETE CASCADE
 );
 
 --
 --------------------------------
 -- Food costs
 --------------------------------
-
-CREATE TABLE food_costs (
-  food_id integer NOT NULL,
-  profile_id integer NOT NULL,
+-- Case for no FK?  e.g. points to food OR custom_food?
+-- Leave edge cases potentially dangling (should never happen)
+-- Does this simplify imports with a potential `guid` column?
+CREATE TABLE food_cost (
+  food_id int,
+  custom_food_id int,
+  profile_id int NOT NULL,
   cost real NOT NULL,
-  PRIMARY KEY (food_id, profile_id),
-  FOREIGN KEY (profile_id) REFERENCES profiles (id) ON UPDATE CASCADE ON DELETE CASCADE
+  PRIMARY KEY (food_id, custom_food_id, profile_id),
+  FOREIGN KEY (custom_food_id) REFERENCES custom_food (id) ON UPDATE CASCADE ON DELETE CASCADE,
+  FOREIGN KEY (profile_id) REFERENCES profile (id) ON UPDATE CASCADE ON DELETE CASCADE
 );
 
+--
+--------------------------------
+-- Bug report, message queues
+--------------------------------
+-- NOTE: be sure to SELECT version (latest) to include on bug report too
+CREATE TABLE bug (
+  id integer PRIMARY KEY AUTOINCREMENT,
+  profile_id int,
+  created int DEFAULT (strftime ('%s', 'now')),
+  arguments text,
+  activity text,
+  stack text,
+  -- e.g. OS, Python / Android version
+  client_info json,
+  -- e.g. app version
+  app_info json,
+  user_details json,
+  submitted tinyint DEFAULT 0,
+  UNIQUE (arguments, stack),
+  FOREIGN KEY (profile_id) REFERENCES profile (id) ON UPDATE CASCADE ON DELETE CASCADE
+);
+
+CREATE TABLE msg (
+  id integer PRIMARY KEY AUTOINCREMENT,
+  profile_id int,
+  msg_id int NOT NULL,
+  created int,
+  received int DEFAULT (strftime ('%s', 'now')),
+  header text,
+  body text,
+  UNIQUE (profile_id, msg_id),
+  FOREIGN KEY (profile_id) REFERENCES profile (id) ON UPDATE CASCADE ON DELETE CASCADE
+);
