@@ -11,13 +11,14 @@ import os
 from ntclient import NUTRA_DIR
 
 # TODO: init, handle when it doesn't exist yet
-# TODO: prompt to create profile if copying default `prefs.json` with PROFILE_ID: -1 (non-existent)
+# TODO: prompt to create profile if copying default `prefs.json` with PROFILE_ID: -1
+#  (non-existent)
 PREFS_FILE = os.path.join(NUTRA_DIR, "prefs.json")
 PREFS = {}
 PROFILE_ID = None
 
 
-def persistence_init():
+def persistence_init() -> None:
     """Loads the preferences file and relevant bits"""
     global PREFS, PROFILE_ID  # pylint: disable=global-statement
     from ntclient import DEBUG  # pylint: disable=import-outside-toplevel
@@ -33,5 +34,6 @@ def persistence_init():
     PROFILE_ID = PREFS.get("current_user")
     if DEBUG and not PROFILE_ID:
         print(
-            "WARN: ~/.nutra/prefs.json doesn't contain valid PROFILE_ID, proceeding in bare mode"
+            "WARN: ~/.nutra/prefs.json doesn't contain valid PROFILE_ID,"
+            "proceeding in bare mode"
         )
