@@ -1,5 +1,5 @@
 """usda.sqlite functions module"""
-from ntclient.persistence.sql.usda import sql
+from ntclient.persistence.sql.usda import sql, sql_headers
 from ntclient.utils import NUTR_ID_KCAL
 
 
@@ -8,35 +8,42 @@ from ntclient.utils import NUTR_ID_KCAL
 ################################################################################
 def sql_fdgrp():
     """Shows food groups"""
+
     query = "SELECT * FROM fdgrp;"
     result = sql(query)
     return {x[0]: x for x in result}
 
 
-def sql_food_details(food_ids=None):
+def sql_food_details(food_ids=None) -> list:
     """Readable human details for foods"""
+
     if food_ids is None:
         query = "SELECT * FROM food_des;"
-        return sql(query)
-    query = "SELECT * FROM food_des WHERE id IN (%s);"
-    food_ids = ",".join(str(x) for x in set(food_ids))
-    return sql(query % food_ids)
+    else:
+        # TODO: does sqlite3 driver support this? cursor.executemany() ?
+        query = "SELECT * FROM food_des WHERE id IN (%s);"
+        food_ids = ",".join(str(x) for x in set(food_ids))
+        query = query % food_ids
+
+    return sql(query)
 
 
 def sql_nutrients_overview() -> dict:
     """Shows nutrients overview"""
+
     query = "SELECT * FROM nutrients_overview;"
     result = sql(query)
     return {x[0]: x for x in result}
 
 
-def sql_nutrients_details() -> list:
+def sql_nutrients_details() -> tuple:
     """Shows nutrients 'details'"""
+
     query = "SELECT * FROM nutrients_overview;"
-    return sql(query, headers=True)
+    return sql_headers(query)
 
 
-def sql_servings(food_ids):
+def sql_servings(food_ids) -> list:
     """Food servings"""
     # TODO: apply connective logic from `sort_foods()` IS ('None') ?
     query = """
@@ -55,7 +62,7 @@ WHERE
     return sql(query % food_ids)
 
 
-def sql_analyze_foods(food_ids):
+def sql_analyze_foods(food_ids) -> list:
     """Nutrient analysis for foods"""
     query = """
 SELECT
@@ -68,6 +75,7 @@ FROM
 WHERE
   food_des.id IN (%s);
 """
+    # TODO: parameterized queries
     food_ids = ",".join(str(x) for x in set(food_ids))
     return sql(query % food_ids)
 
@@ -75,8 +83,9 @@ WHERE
 ################################################################################
 # Sort
 ################################################################################
-def sql_sort_helper1(nutrient_id):
+def sql_sort_helper1(nutrient_id) -> list:
     """Selects relevant bits from nut_data for sorting"""
+
     query = """
 SELECT
   food_id,
@@ -90,11 +99,13 @@ WHERE
 ORDER BY
   food_id;
 """
+
     return sql(query % (NUTR_ID_KCAL, nutrient_id))
 
 
-def sql_sort_foods(nutr_id):
+def sql_sort_foods(nutr_id) -> list:
     """Sort foods by nutr_id per 100 g"""
+
     query = """
 SELECT
   nut_data.food_id,
@@ -114,11 +125,14 @@ WHERE
 ORDER BY
   nut_data.nutr_val DESC;
 """
+
     return sql(query % nutr_id)
 
 
-def sql_sort_foods_by_kcal(nutr_id):
+def sql_sort_foods_by_kcal(nutr_id) -> list:
     """Sort foods by nutr_id per 200 kcal"""
+
+    # TODO: use parameterized queries
     query = """
 SELECT
   nut_data.food_id,
@@ -140,4 +154,5 @@ WHERE
 ORDER BY
   (nut_data.nutr_val / kcal.nutr_val) DESC;
 """
+
     return sql(query % nutr_id)
