@@ -1,9 +1,11 @@
 """Constants and default settings"""
 from colorama import Fore
 
-# ---------------------------
-# Colors and other settings
-# ---------------------------
+################################################################################
+# Colors and buffer settings
+################################################################################
+
+# TODO: make configurable in SQLite or prefs.json
 
 THRESH_WARN = 0.7
 COLOR_WARN = Fore.YELLOW
@@ -12,22 +14,13 @@ THRESH_CRIT = 0.4
 COLOR_CRIT = Fore.RED
 
 THRESH_OVER = 1.9
-# COLOR_OVER = Fore.LIGHTBLACK_EX
-# COLOR_OVER = Fore.LIGHTMAGENTA_EX
-COLOR_OVER = Fore.MAGENTA
+COLOR_OVER = Fore.MAGENTA  # Fore.LIGHTMAGENTA_EX, Fore.LIGHTBLACK_EX
 
-# COLOR_DEFAULT = Fore.BLUE
-# COLOR_DEFAULT = Fore.LIGHTBLUE_EX
-COLOR_DEFAULT = Fore.LIGHTCYAN_EX
+COLOR_DEFAULT = Fore.LIGHTCYAN_EX  # Fore.BLUE, Fore.LIGHTBLUE_EX
 
-SEARCH_LIMIT = 150
-FOOD_NAME_TRUNC = 200
-# int(parameters["FOOD_NAME_TRUNC"]) if "FOOD_NAME_TRUNC" in parameters else 200
-
-
-# ------------------------
+################################################################################
 # Nutrient IDs
-# ------------------------
+################################################################################
 NUTR_ID_KCAL = 208
 
 NUTR_ID_PROTEIN = 203
@@ -41,7 +34,6 @@ NUTR_ID_FAT_SAT = 606
 NUTR_ID_FAT_MONO = 645
 NUTR_ID_FAT_POLY = 646
 
-
 NUTR_IDS_FLAVONES = [
     710,
     711,
